==> Banners-2.3.7.tar.gz: Banners/lang/ext/hu_HU.php <==
<?php
$lang['error_bannerexists'] = 'Ilyen nevű banner m&aacute;r l&eacute;tezik';
$lang['accessdenied'] = 'Hozz&aacute;f&eacute;r&eacute;s megtagadva. Ellenőrizd a jogosults&aacute;gokat.';
$lang['addbanner'] = 'Banner hozz&aacute;ad&aacute;sa';
$lang['addcategory'] = 'Kateg&oacute;ria hozz&aacute;ad&aacute;sa';
$lang['areyousure'] = 'Biztosan ezt akarod?';
$lang['banners'] = 'Bannerek';
$lang['cancel'] = 'M&eacute;gsem';
$lang['categories'] = 'Kateg&oacute;ri&aacute;k';
$lang['category'] = 'Kateg&oacute;ria';
$lang['created'] = 'L&eacute;trehozva';
$lang['date'] = 'D&aacute;tum';
$lang['delete'] = 'T&ouml;rl&eacute;s';
$lang['description'] = 'Le&iacute;r&aacute;s';
$lang['edit'] = 'Szerkeszt';
$lang['editcategory'] = 'Kateg&oacute;ria szerkeszt&eacute;se';
$lang['error'] = 'Hiba!';
$lang['error_banerexists'] = 'Ilyen nevű banner m&aacute;r van';
$lang['error_categorynotempty'] = 'Hiba: a kateg&oacute;ria nem &uuml;res!';
$lang['error_dberror'] = 'Hiba: adatb&aacute;zis hiba!';
$lang['error_emptybannername'] = 'Hiba: &uuml;res banner n&eacute;v!';
$lang['error_emptycategory'] = 'Hiba: &uuml;res kateg&oacute;ria!';
$lang['error_insufficientparams'] = 'Hiba: nem elegendő input';
$lang['error_nocategories'] = 'Hiba: nem tal&aacute;ltam kateg&oacute;ri&aacute;kat';
$lang['error_noresults'] = 'Egy kateg&oacute;ria sem felelet meg a k&eacute;r&eacute;snek';
$lang['error_textorimage'] = 'Adj meg URL-t &eacute;s k&eacute;pet vagy sz&ouml;veget, de mindkettőt!';
$lang['expires'] = 'Lej&aacute;r';
$lang['friendlyname'] = 'Bannerek kezel&eacute;se';
$lang['height'] = 'Magass&aacute;g';
$lang['hits'] = 'Tal&aacute;latok';
$lang['href_text'] = 'Link sz&ouml;vege';
$lang['id'] = 'Azonos&iacute;t&oacute;';
$lang['image'] = 'K&eacute;p';
$lang['image_text'] = 'Alt k&eacute;p sz&ouml;veg';
$lang['impressions'] = 'Megtekint&eacute;sek';
$lang['info_href_text'] = 'Plusz sz&ouml;veg a link tag-hoz. Ez a sz&ouml;veg bet&uuml;ről bet&uuml;re ker&uuml;l a link tag-hoz.';
$lang['info_image'] = 'A file-t az uploads k&ouml;nyvt&aacute;rhoz k&eacute;pest relat&iacute;ven add meg.';
$lang['info_image_text'] = 'Plusz sz&ouml;veg a k&eacute;p tag-hoz.';
$lang['info_max_hits'] = 'Adj meg 0-t, &eacute;s nem lesz tal&aacute;lati korl&aacute;t';
$lang['info_max_impressions'] = 'Adj meg 0-t, &eacute;s nem lesz megtekint&eacute;s korl&aacute;t';
$lang['installed'] = '%s verzi&oacute;j&uacute; modul telep&iacute;tve van.';
$lang['ipaddress'] = 'IP c&iacute;m';
$lang['max_hits'] = 'Tal&aacute;latok maxim&aacute;lis sz&aacute;ma';
$lang['max_impressions'] = 'Megtekint&eacute;sek maxim&aacute;lis sz&aacute;ma';
$lang['name'] = 'N&eacute;v';
$lang['never'] = 'Soha';
$lang['postinstall'] = 'Post Install Message, e.g., Be sure to set &quot;Manage Banners&quot; permissions to use this module!';
$lang['postuninstall'] = 'Banners module uninstalled, and all database tables removed.  Sorry to see you leave.&quot;';
$lang['preferences'] = 'Preferenci&aacute;k';
$lang['prefsupdated'] = 'A modul preferenci&aacute;k friss&iacute;t&eacute;se megt&ouml;rt&eacute;nt.';
$lang['prompt_categorydesc'] = 'Kateg&oacute;ria le&iacute;r&aacute;s';
$lang['prompt_categoryname'] = 'Kateg&oacute;ria neve';
$lang['prompt_imageheight'] = 'K&eacute;p magass&aacute;g';
$lang['prompt_imagewidth'] = 'K&eacute;p sz&eacute;less&eacute;g';
$lang['prompt_subnet_exclusions'] = 'Ezen alh&aacute;l&oacute;zatok kiz&aacute;r&aacute;sa a statsztik&aacute;b&oacute;l';
$lang['prompt_upload_category'] = 'Kateg&oacute;ria (Uploads Modul)';
$lang['prompt_upload_file'] = 'K&eacute;p (Uploads Modul)';
$lang['selectcategory'] = 'Kateg&oacute;ria kiv&aacute;laszt&aacute;sa';
$lang['submit'] = 'Mehet';
$lang['text'] = 'Sz&ouml;veg';
$lang['title_mod_admin'] = 'Modul Admin Panel';
$lang['title_mod_prefs'] = 'Modul preferenci&aacute;k';
$lang['uninstalled'] = 'A modul elt&aacute;vol&iacute;t&aacute;sa megt&ouml;rt&eacute;nt.';
$lang['upgraded'] = 'A modult friss&iacute;tett&uuml;k a(z) %s verzi&oacute;ra.';
$lang['url'] = 'URL ';
$lang['width'] = 'Sz&eacute;less&eacute;g';
$lang['title_admin_panel'] = 'Banners Modul';
$lang['moddescription'] = 'Forg&oacute; banner-ek kezel&eacute;s&eacute;t ell&aacute;t&oacute; modul';
$lang['welcome_text'] = '<p>&Uuml;dv&ouml;zl&uuml;nk a Banner Kezelő Modul admin szekci&oacute;j&aacute;ban. Valami m&aacute;s is lehetne itt, ha lenne &eacute;rtelme, de nincs.</p>';
$lang['changelog'] = '<ul>
<li>Version 1.0. 6 August 2005. Initial Release.</li>
<li>Version 2.0. September 2005. Initial Release for 0.1..</li>
<li>Version 2.0.1. September 2005. Display sample banner in the edit banner page, added name= parameter, and made subnet exclusions work.  Also changed the definition of the database to allow for additional text in the link and image tags.</li>
<li>Version 2.0.2. September 2005. Added integration with the uploads module (1.0.6) so that we can get lits of files for banners, etc.  The banners module is still optional though.</li>
<li>Version 2.0.3. September 2005. Fixed a very minor issue with never expires..</li>
<li>Version 2.0.4. September 2005. Fixed a very minor issue with module dependencies, and a big bug in the database spec if you did a scratch install.</li>
<li>Version 2.0.5. October 2005. Add coments around the output</li>
<li>Version 2.0.6. December 2005. Minor validation fixes, description is now output between the <img>and</img> tags, and an alt attribute is in the img tag.</li>
<li>Version 2.0.7. January 2006. More validation fixes, Moved the admin tabs around, fixed an issue where you could almost create a banner without defining a category, and... fixed the expiry date issue for good (hopefully).</li>
<li>Version 2.1.0. August 2006. Prepared for 1.0 compatibility, split into multiple files, used references where possible, improved messages, and a general cleanup.</li>
</ul>';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>This banner manages numerous categories of banners, tracks hits, impressions, and expiry dates, and randomly selects from all available and valid banners for one to display</p>
<h3>How Do I Use It</h3>
<p>To use this module, place the module code in a page or template using the smarty tag {cms_module module=&#039;Banners&#039; category=&quot;<category>&quot;}</p> 
<p>You must also upload banners to a suitable directory within the uploads directory and must use the admin panel interface to add banners to the database.</p
<h3>Parameters</h3>
<ul>
<li><em>(REQUIRED)</em> category=&quot;category&quot; = randomly select from all available in this category</li>
<li><em>(optional)</em> name=&quot;name&quot; = select only the banner with this name</li>
<li><em>(optional)</em> mode=&quot;sequential&quot; = Instead of randomly selecting a valid banner, select the one with the least impressions.</li>
</ul>
<h4>Hint</h4>
<p>The uploads module and the banners module work well together.  You can create a &quot;banners&quot; category in the uploads module, and upload your banner images there, then specify &quot;banners/<filename>&quot; when adding a banner in the banners module.</p>';
$lang['utmz'] = '156861353.1199203774.93.7.utmccn=(referral)|utmcsr=dev.cmsmadesimple.org|utmcct=/my/|utmcmd=referral';
$lang['utma'] = '156861353.1745742775.1167462096.1201941642.1202537193.101';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
?>

==> Banners-2.5.3.tar.gz: Banners/lang/ext/hu_HU.php <==
<?php
$lang['statreport_linesperpage'] = 'Lines per page on the statistics report';
$lang['banner'] = 'Banner Advertisement';
$lang['of'] = 'Of';
$lang['page'] = 'Page';
$lang['generated'] = 'K&eacute;sz&iacute;tett';
$lang['generated_by'] = 'K&eacute;sz&iacute;tette';
$lang['desc_stats_report'] = 'A report illustrating the number of impressions and click-through hits from the Banners module';
$lang['title_stats_report'] = 'Banner Statistics Report';
$lang['view_statistics'] = 'View Statistics';
$lang['msg_new_window'] = 'Creates a new window';
$lang['statreport_template'] = 'Statistics Report Template';
$lang['your_ad_here'] = 'Your Advertisement could be here';
$lang['prompt_dflt_image'] = 'Alap&eacute;rtelmezett k&eacute;p';
$lang['prompt_dflt_url'] = 'Alap&eacute;rtelmezett URL';
$lang['info_dflt_image'] = 'Specify an image name (relative to the uploads directory) of an image to use when no banners are valid to be displayed';
$lang['prompt_hidefrombots'] = 'Exclude robots from impression counting';
$lang['help_param_action'] = 'Specify the behaviour of the module.  Possible values are &quot;default&quot; and &quot;list&quot;.  The default action is used for displaying a single banner according to specified criterium.  The list action is used to display all of the banners of a specified category or category id';
$lang['help_param_category'] = 'In the default action, this parameter is used to specify the name of the category from which a single banner will be displayed.  In the list action this parameter is required to specify the name of the category from which all banners will be displayed';
$lang['help_param_mode'] = 'This parameter is only used in the default action, it specifies the way in which banners are selected from the specified category.  The only value is &quot;sequential&quot; which indicates that the module should choose the next non expired banner with the least amount of impressions.  Not specifying this parameter will result in a random banner being selected';
$lang['help_param_name'] = 'This parameter is only used in the default action.  It specifies an absolute name of a banner to load.  However, if the banner is invalid (the number of impressions has been reached, OR it has expired), nothing will be returned.';
$lang['bannerlist_template'] = 'Banner List Template';
$lang['info_bannerlist_template'] = 'Used with the list action, this template controls the dispay of all banners in the selected category';
$lang['none'] = 'Egyik sem';
$lang['error_invalid_dates'] = 'Error Invalid Dates';
$lang['editbanner'] = 'Banner szerkeszt&eacute;s';
$lang['start_date'] = 'Kezd&eacute;s d&aacute;tuma';
$lang['atttext'] = 'at';
$lang['template'] = 'Sablon';
$lang['default_template'] = 'Default Category Template';
$lang['reset_template'] = 'Reset Template to Defaults';
$lang['error_banners'] = 'Nincs banner';
$lang['error_bannerexists'] = 'Ilyen nevű banner m&aacute;r l&eacute;tezik';
$lang['accessdenied'] = 'Hozz&aacute;f&eacute;r&eacute;s megtagadva. Ellenőrizd a jogosults&aacute;gokat.';
$lang['addbanner'] = 'Banner hozz&aacute;ad&aacute;sa';
$lang['addcategory'] = 'Kateg&oacute;ria hozz&aacute;ad&aacute;sa';
$lang['areyousure'] = 'Biztosan ezt akarod?';
$lang['banners'] = 'Bannerek';
$lang['cancel'] = 'M&eacute;gsem';
$lang['categories'] = 'Kateg&oacute;ri&aacute;k';
$lang['category'] = 'Kateg&oacute;ria';
$lang['created'] = 'L&eacute;trehozva';
$lang['date'] = 'D&aacute;tum';
$lang['delete'] = 'T&ouml;rl&eacute;s';
$lang['description'] = 'Le&iacute;r&aacute;s';
$lang['edit'] = 'Szerkeszt';
$lang['editcategory'] = 'Kateg&oacute;ria szerkeszt&eacute;se';
$lang['error'] = 'Hiba!';
$lang['error_banerexists'] = 'Ilyen nevű banner m&aacute;r van';
$lang['error_categorynotempty'] = 'Hiba: a kateg&oacute;ria nem &uuml;res!';
$lang['error_dberror'] = 'Hiba: adatb&aacute;zis hiba!';
$lang['error_emptybannername'] = 'Hiba: &uuml;res banner n&eacute;v!';
$lang['error_emptycategory'] = 'Hiba: &uuml;res kateg&oacute;ria!';
$lang['error_insufficientparams'] = 'Hiba: nem elegendő input';
$lang['error_nocategories'] = 'Hiba: nem tal&aacute;ltam kateg&oacute;ri&aacute;kat';
$lang['error_noresults'] = 'Egy kateg&oacute;ria sem felelet meg a k&eacute;r&eacute;snek';
$lang['error_textorimage'] = 'Adj meg URL-t &eacute;s k&eacute;pet vagy sz&ouml;veget, de mindkettőt!';
$lang['expires'] = 'Lej&aacute;r';
$lang['friendlyname'] = 'Bannerek kezel&eacute;se';
$lang['height'] = 'Magass&aacute;g';
$lang['hits'] = 'Tal&aacute;latok';
$lang['href_text'] = 'Link sz&ouml;vege';
$lang['id'] = 'Azonos&iacute;t&oacute;';
$lang['image'] = 'K&eacute;p';
$lang['image_text'] = 'Alt k&eacute;p sz&ouml;veg';
$lang['impressions'] = 'Megtekint&eacute;sek';
$lang['info_href_text'] = 'Plusz sz&ouml;veg a link tag-hoz. Ez a sz&ouml;veg bet&uuml;ről bet&uuml;re ker&uuml;l a link tag-hoz.';
$lang['info_image'] = 'A file-t az uploads k&ouml;nyvt&aacute;rhoz k&eacute;pest relat&iacute;ven add meg.';
$lang['info_image_text'] = 'Plusz sz&ouml;veg a k&eacute;p tag-hoz.';
$lang['info_max_hits'] = 'Adj meg 0-t, &eacute;s nem lesz tal&aacute;lati korl&aacute;t';
$lang['info_max_impressions'] = 'Adj meg 0-t, &eacute;s nem lesz megtekint&eacute;s korl&aacute;t';
$lang['installed'] = '%s verzi&oacute;j&uacute; modul telep&iacute;tve van.';
$lang['ipaddress'] = 'IP c&iacute;m';
$lang['max_hits'] = 'Tal&aacute;latok maxim&aacute;lis sz&aacute;ma';
$lang['max_impressions'] = 'Megtekint&eacute;sek maxim&aacute;lis sz&aacute;ma';
$lang['name'] = 'N&eacute;v';
$lang['never'] = 'Soha';
$lang['postinstall'] = 'Post Install Message, e.g., Be sure to set &quot;Manage Banners&quot; permissions to use this module!';
$lang['postuninstall'] = 'Banner modulokat &eacute;s az &ouml;sszes adatb&aacute;zis t&aacute;bl&aacute;t t&ouml;r&ouml;lt&uuml;k. Sajn&aacute;ljuk, hogy elm&eacute;sz.';
$lang['preferences'] = 'Preferenci&aacute;k';
$lang['prefsupdated'] = 'A modul preferenci&aacute;k friss&iacute;t&eacute;se megt&ouml;rt&eacute;nt.';
$lang['prompt_categorydesc'] = 'Kateg&oacute;ria le&iacute;r&aacute;s';
$lang['prompt_categoryname'] = 'Kateg&oacute;ria neve';
$lang['prompt_imageheight'] = 'K&eacute;p magass&aacute;g';
$lang['prompt_imagewidth'] = 'K&eacute;p sz&eacute;less&eacute;g';
$lang['prompt_subnet_exclusions'] = 'Ezen alh&aacute;l&oacute;zatok kiz&aacute;r&aacute;sa a statsztik&aacute;b&oacute;l';
$lang['prompt_upload_category'] = 'Kateg&oacute;ria (Uploads Modul)';
$lang['prompt_upload_file'] = 'K&eacute;p (Uploads Modul)';
$lang['selectcategory'] = 'Kateg&oacute;ria kiv&aacute;laszt&aacute;sa';
$lang['submit'] = 'Mehet';
$lang['text'] = 'Sz&ouml;veg';
$lang['title_mod_admin'] = 'Modul Admin Panel';
$lang['title_mod_prefs'] = 'Modul preferenci&aacute;k';
$lang['uninstalled'] = 'A modul elt&aacute;vol&iacute;t&aacute;sa megt&ouml;rt&eacute;nt.';
$lang['upgraded'] = 'A modult friss&iacute;tett&uuml;k a(z) %s verzi&oacute;ra.';
$lang['url'] = 'URL ';
$lang['width'] = 'Sz&eacute;less&eacute;g';
$lang['title_admin_panel'] = 'Banners Modul';
$lang['moddescription'] = 'Forg&oacute; banner-ek kezel&eacute;s&eacute;t ell&aacute;t&oacute; modul';
$lang['welcome_text'] = '<p>&Uuml;dv&ouml;zl&uuml;nk a Banner Kezelő Modul admin szekci&oacute;j&aacute;ban. Valami m&aacute;s is lehetne itt, ha lenne &eacute;rtelme, de nincs.</p>';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>This banner manages numerous categories of banners, tracks hits, impressions, and expiry dates, and randomly selects from all available and valid banners for one to display</p>
<h3>How Do I Use It</h3>
<p>To use this module, place the module code in a page or template using the smarty tag {cms_module module=&#039;Banners&#039; category=&quot;<category>&quot;}</p> 
<p>You must also upload banners to a suitable directory within the uploads directory and must use the admin panel interface to add banners to the database.</p
<h3>Parameters</h3>
<ul>
<li><em>(REQUIRED)</em> category=&quot;category&quot; = randomly select from all available in this category</li>
<li><em>(optional)</em> name=&quot;name&quot; = select only the banner with this name</li>
<li><em>(optional)</em> mode=&quot;sequential&quot; = Instead of randomly selecting a valid banner, select the one with the least impressions.</li>
</ul>
<h4>Hint</h4>
<p>The uploads module and the banners module work well together.  You can create a &quot;banners&quot; category in the uploads module, and upload your banner images there, then specify &quot;banners/<filename>&quot; when adding a banner in the banners module.</p>';
$lang['utma'] = '156861353.251908092.1300186365.1300186365.1300186365.1';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
$lang['utmz'] = '156861353.1300186365.1.1.utmccn=(referral)|utmcsr=cmsmadesimple.hu|utmcct=/forum/index.php/topic,477.15.html|utmcmd=referral';
?>
